@@ -1,7 +1,7 @@
 package SQL::Interpolate::Filter;
 
 use strict;
-#use warnings;
+use warnings;
 use Filter::Simple;
 use Text::Balanced qw/extract_quotelike
                       extract_bracketed
@@ -9,7 +9,7 @@ use Text::Balanced qw/extract_quotelike
                       extract_variable
                       extract_codeblock/;
 
-our $VERSION = $SQL::Interpolate::VERSION;
+our $VERSION = '0.32';
 
 # Source filter.
 # Note: this could be improved as done in the POD of the development 2.0 version of
@@ -18,22 +18,22 @@ FILTER {
     my $id = qr/\b(?!([ysm]|q[rqxw]?|tr)\b)\w+/;
 
     # This lexes the Perl source code, replacing quotelike sql//
-    # operators with the result of process_sql().
-    while($_ !~ /\G$/gc) {
+    # operators with the result of _process_sql().
+    while ($_ !~ /\G$/gc) {
         my $sql;
         my $last_pos = pos();
-        if(/\G\s+/gc) { }    # whitespace
-        elsif(/\G#.*/gc) { } # comments
+        if    (/\G\s+/gc) { }  # whitespace
+        elsif (/\G#.*/gc) { }  # comments
         # sql// operators
         # FIX:should any other quote delimiters be added?
-        elsif(/\G\bsql\b\s*(?=[\{\(\[\<\/])/gcs &&
+        elsif (/\G\bsql\b\s*(?=[\{\(\[\<\/])/gcs &&
             do {
                 my $pos = pos();
-                s/\G/ q/; # convert to Perl quote-like
+                s/\G/ q/;  # convert to Perl quote-like
                 pos() = $pos;
                 $sql = (extract_quotelike())[5];
                 #print "<sql:$sql>";
-                if(!$sql) { # restore
+                if (!$sql) {  # restore
                     s/\G q//;
                     pos() = $pos;
                 }
@@ -42,19 +42,19 @@ FILTER {
         )
         {
             my $pos = pos();
-            my $out = &process_sql($sql);
+            my $out = _process_sql($sql);
             pos() = $pos;
             substr($_, $last_pos, pos() - $last_pos) = $out;
             pos() = $last_pos + length($out);
         }
         # prevent things like $y = ... = from being interpreted as string.
-        elsif(/\G(?<=[\$\@])\w+/gc) {
+        elsif (/\G(?<=[\$\@])\w+/gc) {
             #print "[DEBUG:var:$&]";
         }
-        elsif(/\G$id/gc) {
+        elsif (/\G$id/gc) {
             #print "[DEBUG:id:$&]";
         }
-        elsif(my $next = (extract_quotelike())[0]) {
+        elsif (my $next = (extract_quotelike())[0]) {
             #print "[DEBUG:q:$next]";
         }
         else {
@@ -66,24 +66,23 @@ FILTER {
 
 # Convert the string inside a sql// quote-like operator into
 # a list of SQL strings and variable references for interpolation.
-sub process_sql
-{
+sub _process_sql {
     local $_ = shift;
 
     my @parts;
     my $instr = 0;
-    while($_ !~ /\G$/gc) {
+    while ($_ !~ /\G$/gc) {
         my $tok;
         my $tok_type;
         my $pos_last = pos();
-        if(/\G(\s+|\*)/gc) {
+        if (/\G(\s+|\*)/gc) {
             $tok = $1;
             $tok_type = 's';
         }
-        elsif($tok = (extract_variable($_))[0]) {
+        elsif ($tok = (extract_variable($_))[0]) {
             $tok_type = 'v';
         }
-        elsif($tok = (extract_codeblock($_, '{['))[0]) {
+        elsif ($tok = (extract_codeblock($_, '{['))[0]) {
             $tok_type = 'c';
         }
         else {
@@ -92,8 +91,8 @@ sub process_sql
             $tok_type = 's';
         }
 
-        if($tok_type eq 's') {
-            if($instr) {
+        if ($tok_type eq 's') {
+            if ($instr) {
                 $parts[-1] .= $tok
             }
             else {
@@ -104,41 +103,27 @@ sub process_sql
         else {
             $parts[-1] = 'qq[' . $parts[-1] . ']' if $instr;
             $instr = 0;
-            if($tok_type eq 'v') {
+            if ($tok_type eq 'v') {
                 push @parts, '\\' . $tok;
             }
-            elsif($tok_type eq 'c') {
+            elsif ($tok_type eq 'c') {
                 push @parts, $tok;
             }
-            elsif($tok_type eq 'limit') {
-                # note: full package name to not require import
-                push @parts, "SQL::Interpolate::Limit->new$tok";
-            }
             else { die 'assert'; }
         }
 
     }
     $parts[-1] = 'qq[' . $parts[-1] . ']' if $instr;
-    #use Data::Dumper; die "[DEBUG_SQL_PARTS:" . Dumper(\@parts) . "]";
 
-    my $out = 'SQL::Interpolate::SQL->new(' . join(', ', @parts) . ')';
+    my $out = 'SQL::Interpolate::Filter::_make_sql('
+            . join(', ', @parts) . ')';
 
     return $out;
 }
 
-1;
-
-package SQL::Interpolate::SQL;
 # Generated by the sql// operator when source filtering is enabled.
-
-use strict;
-use base qw(Exporter SQL::Interpolate::Macro);
-use overload '.'  => \&concat,
-             '""' => \&stringify;
-
-sub new
-{
-    my($class, @list) = @_;
+sub _make_sql {
+    my (@list) = @_;
 
     # Note that sql[INSERT INTO mytable $x] gets translated to
     #   q[INSERT INTO mytable], \$x
@@ -146,42 +131,14 @@ sub new
     # would be difficult to know at source filtering time whether
     # $x is already a reference.  Therefore, we dereference any
     # double reference here (at run-time).
-    do { $_ = $$_ if ref($_) eq 'REF' } for @list;
+    do { $_ = $$_ if ref($_) eq 'REF' }
+        for @list;
 
-    my $self = {
-        list => \@list
-    };
-    bless $self, $class;
-    return $self;
+    my $o = SQL::Interpolate::SQL->new(@list);
+    return $o;
 }
 
-# implements SQL::Interpolate::Macro
-sub expand
-{
-    my $self = shift;
-    return @{$self->{list}};
-}
-
-# Concatenate SQL object with another expression.
-# An SQL object can be concatenated with another SQL object,
-# variable reference, or an SQL string.
-sub concat
-{
-    my($a, $b, $inverted) = @_;
-
-    my @params = ( @{$a->{list}},
-                   ref($b) eq __PACKAGE__ ? @{$b->{list}} : ($b) );
-    ($params[0], $params[1]) = ($params[1], $params[0]) if $inverted;
-    my $c = new SQL::Interpolate::SQL(@params);
-
-    return $c;
-}
-
-sub stringify
-{
-    my($a) = @_;
-    return $a;
-}
+1;
 
 # Implementation Notes:
 # Sub::Quotelike provides similar functionality to this module,
@@ -238,7 +195,7 @@ SQL and Perl variables.
 Source filtering will transform this construct into a constructor for
 a macro object that simply contains the filtered interpolation list:
 
-  SQL::Interpolate::SQL->new("SELECT * FROM mytable WHERE x = ", \$x);
+  SQL::Interpolate::Filter::_make_sql("SELECT * FROM mytable WHERE x = ", \$x);
 
 The macro expands into the contained interpolation list,
 which C<sql_interp> (or C<dbi_interp>) can then interpolate as usual:
@@ -313,9 +270,14 @@ The source code of the module after source filtering will be sent
 to STDERR.
 
  ...
- SQL::Interpolate::SQL->new(qq[SELECT * FROM mytable WHERE x = ], \$x)
+ SQL::Interpolate::Filter::_make_sql(qq[SELECT * FROM mytable WHERE x = ], \$x)
  ...
 
+=head1 DEPENDENCIES
+
+This module depends on SQL::Interpolate, Filter::Simple (any),
+and Text::Balanced >= 1.87.
+
 =head1 DESIGN NOTES
 
 =head2 Limitations / characteristics
